==> ogstools-0.1.0-py3-none-any.whl: ogstools/meshplotlib/plot_setup_defaults.py <==
"""
.. literalinclude:: ../../ogstools/meshplotlib/plot_setup_defaults.py
   :language: python
   :linenos:
   :lines: 9-

"""

setup_dict = {
    "default_cmap": "RdBu_r",
    "dpi": 200,
    "fig_scale": 1.0,
    "figsize": [24, 11],
    "invert_colorbar": False,
    "length": ["m", "m"],
    "material_names": None,
    "num_levels": 11,
    "num_streamline_interp_pts": 50,
    "p_min": None,
    "p_max": None,
    "scale_type": "auto",
    "show_aspect_ratio": False,
    "show_element_edges": "MaterialIDs",
    "show_region_bounds": True,
    "title_center": "",
    "title_left": "",
    "title_right": "",
    "x_label": None,
    "y_label": None,
    "log_scaled": False,
    "cmap_dict": {
        "displacement": "Greens",
        "temperature": ["Blues", "plasma"],
        "pressure": "Blues",
        "velocity": "coolwarm",
        "MaterialIDs": "tab20",
    },
    "cmap_dict_if_component": {"displacement": "PRGn"},
    "cmap_if_mask": ["yellow", "green"],
    "rcParams": {
        "font.weight": "normal",
        "font.family": "sans-serif",
        "font.size": 32,
        "axes.titlesize": "medium",
        "axes.labelsize": "medium",
        "axes.labelpad": 12,
        "axes.grid": False,
        "legend.fontsize": "medium",
        "xtick.labelsize": "medium",
        "ytick.labelsize": "medium",
        "axes.linewidth": 1,
        "lines.linewidth": 1,
        "legend.framealpha": 1,
        "mathtext.fontset": "dejavuserif",
        "xtick.major.pad": 12,
        "xtick.major.size": 12,
        "xtick.direction": "in",
        "ytick.major.pad": 12,
        "ytick.major.size": 12,
        "ytick.direction": "in",
    },
}

==> ogstools-0.2.0-py3-none-any.whl: ogstools/meshplotlib/plot_setup_defaults.py <==
"""
.. literalinclude:: ../../ogstools/meshplotlib/plot_setup_defaults.py
   :language: python
   :linenos:
   :lines: 9-

"""

setup_dict = {
    "default_cmap": "RdBu_r",
    "dpi": 120,
    "fig_scale": 1.0,
    "ax_aspect_limits": (0.4, 2.2),
    "fig_aspect_limits": (0.2, 5.0),
    "invert_colorbar": False,
    "layout": "constrained",
    "length": ["m", "m"],
    "material_names": None,
    "num_levels": 11,
    "num_streamline_interp_pts": 50,
    "p_min": None,
    "p_max": None,
    "scale_type": "auto",
    "show_element_edges": "MaterialIDs",
    "show_region_bounds": True,
    "embedded_region_names_color": None,
    "title_center": "",
    "title_left": "",
    "title_right": "",
    "x_label": None,
    "y_label": None,
    "log_scaled": False,
    "combined_colorbar": True,
    "custom_cmap": None,
    "cmap_dict": {
        "displacement": "Greens",
        "temperature": ["Blues", "plasma"],
        "pressure": "Blues",
        "velocity": "coolwarm",
        "MaterialIDs": "tab20",
    },
    "cmap_dict_if_bilinear": {"displacement": "PRGn"},
    "cmap_if_mask": ["lightgrey", "green"],
    "rcParams": {
        "font.weight": "normal",
        "font.family": "sans-serif",
        "font.size": 32,
        "axes.titlesize": "medium",
        "axes.labelsize": "medium",
        "axes.labelpad": 12,
        "axes.grid": False,
        "legend.fontsize": "medium",
        "xtick.labelsize": "medium",
        "ytick.labelsize": "medium",
        "axes.linewidth": 1,
        "lines.linewidth": 1,
        "legend.framealpha": 1,
        "mathtext.fontset": "dejavuserif",
        "xtick.major.pad": 12,
        "xtick.major.size": 12,
        "xtick.direction": "in",
        "ytick.major.pad": 12,
        "ytick.major.size": 12,
        "ytick.direction": "in",
    },
}
